@@ -31,15 +31,21 @@ They are not meant to be used directly. See :py:mod:`bluetooth_mesh.application`
 
 import asyncio
 import logging
+import os
+import socket
+import os
 from collections import defaultdict
+from contextlib import suppress
 from datetime import timedelta
-from typing import Any, Dict, Mapping, Optional, Tuple
+from enum import Enum
+from typing import Any, Dict, Mapping, Optional, Sequence, Tuple
 from uuid import UUID
 
 from dbus_next import DBusError, Variant
 from dbus_next.service import PropertyAccess, ServiceInterface, dbus_property, method
 
 from bluetooth_mesh.crypto import ApplicationKey, DeviceKey, NetworkKey
+from bluetooth_mesh.utils import Signal
 
 
 class DBusService:
@@ -284,6 +290,17 @@ class NetworkInterface:
     def __init__(self, mesh_service):
         self._interface = mesh_service.get_interface("org.bluez.mesh.Network1")
 
+    def _extract_model_config(self, configuration):
+        configuration_dict = defaultdict(dict)
+
+        for element, element_conf in configuration:
+            for model_id, model_conf in element_conf:
+                vendor_id, model_conf_dict = extract_model_config(model_conf)
+
+                configuration_dict[element][(vendor_id, model_id)] = model_conf_dict
+
+        return configuration_dict
+
     async def join(self, app_defined_root: str, uuid: UUID) -> None:
         await self._interface.call_join(app_defined_root, uuid.bytes)
 
@@ -295,15 +312,43 @@ class NetworkInterface:
     ) -> Tuple[str, Dict[int, Dict[Tuple[Optional[int], int], Mapping[str, Any]]]]:
         path, configuration = await self._interface.call_attach(app_defined_root, token)
 
-        configuration_dict = defaultdict(dict)
+        return path, self._extract_model_config(configuration)
 
-        for element, element_conf in configuration:
-            for model_id, model_conf in element_conf:
-                vendor_id, model_conf_dict = extract_model_config(model_conf)
+    async def attach_fd(
+        self, app_defined_root: str, token: int
+    ) -> Tuple[
+        str,
+        Dict[int, Dict[Tuple[Optional[int], int], Mapping[str, Any]]],
+        socket.socket
+    ]:
+        path, configuration, fd = await self._interface.call_attach_fd(
+            app_defined_root, token
+        )
 
-                configuration_dict[element][(vendor_id, model_id)] = model_conf_dict
+        sock = socket.fromfd(fd, socket.AF_UNIX, socket.SOCK_DGRAM)
+        sock.setblocking(False)
 
-        return path, configuration_dict
+        return path, self._extract_model_config(configuration), sock
+
+    async def attach_unix(
+        self, app_defined_root: str, token: int, socket_path: str
+    ) -> Tuple[
+        str,
+        Dict[int, Dict[Tuple[Optional[int], int], Mapping[str, Any]]],
+        socket.socket,
+    ]:
+        with suppress(FileNotFoundError):
+            os.unlink(socket_path)
+
+        sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM, 0)
+        sock.setblocking(False)
+        sock.bind(socket_path)
+
+        path, configuration = await self._interface.call_attach_unix(
+            app_defined_root, token, socket_path
+        )
+
+        return path, self._extract_model_config(configuration), sock
 
     async def leave(self, token: int) -> None:
         await self._interface.call_leave(token)
@@ -350,9 +395,40 @@ class AclInterface:
         return await self._interface.call_revoke_access(token)
 
 
+class IvState(Enum):
+    INIT = "init"
+    NORMAL = "normal"
+    UPDATING = "updating"
+    NORMAL_HOLD = "hold"
+
+
 class NodeInterface:
     def __init__(self, node_service):
         self._interface = node_service.get_interface("org.bluez.mesh.Node1")
+        self._properties = node_service.get_interface("org.freedesktop.DBus.Properties")
+        self._properties.on_properties_changed(self._on_properties_changed)
+
+    def _on_properties_changed(
+        self, interface: str, changed: Mapping[str, Any], invalidated: Sequence[str]
+    ):
+        if interface != "org.bluez.mesh.Node1":
+            return
+
+        for name, variant in changed.items():
+            val = variant.value
+
+            if name == "IvIndex":
+                sig = self.iv_index.signal
+            elif name == "IvUpdate":
+                sig = self.iv_udpate.signal
+            elif name == "IvState":
+                sig = self.iv_state.signal
+                val = IvState(variant.value)
+            else:
+                sig = None
+
+            if sig:
+                asyncio.ensure_future(sig.emit(val))
 
     async def send(
         self, element_path: str, destination: int, key_index: int, data: bytes
@@ -418,9 +494,19 @@ class NodeInterface:
     async def iv_update(self) -> bool:
         return await self._interface.get_iv_update()
 
+    iv_update.signal = Signal()
+
     async def iv_index(self) -> int:
         return await self._interface.get_iv_index()
 
+    iv_index.signal = Signal()
+
+    async def iv_state(self) -> IvState:
+        state = await self._interface.get_iv_state()
+        return IvState(state)
+
+    iv_state.signal = Signal()
+
     async def seconds_since_last_heard(self) -> int:
         return await self._interface.get_seconds_since_last_heard()
 
