@@ -39,10 +39,10 @@ from bluetooth_mesh.messages.config import (
 )
 from bluetooth_mesh.messages.generic.level import GenericLevelOpcode
 from bluetooth_mesh.messages.generic.light.ctl import LightCTLOpcode
-from bluetooth_mesh.messages.generic.light.lightness import LightLightnessOpcode
+from bluetooth_mesh.messages.generic.light.lightness import LightLightnessOpcode, LightLightnessSetupOpcode
 from bluetooth_mesh.messages.generic.onoff import GenericOnOffOpcode
 from bluetooth_mesh.messages.health import HealthOpcode
-from bluetooth_mesh.messages.scene import SceneMessageOpcode
+from bluetooth_mesh.messages.scene import SceneOpcode
 from bluetooth_mesh.messages.sensor import SensorOpcode
 from bluetooth_mesh.messages.silvair.debug import DebugOpcode, DebugSubOpcode
 from bluetooth_mesh.messages.silvair.gateway_config_server import (
@@ -1142,16 +1142,16 @@ class GenericOnOffClient(Model):
 class SceneClient(Model):
     MODEL_ID = (None, 0x1205)
     OPCODES = {
-        SceneMessageOpcode.SCENE_GET,
-        SceneMessageOpcode.SCENE_RECALL,
-        SceneMessageOpcode.SCENE_RECALL_UNACKNOWLEDGED,
-        SceneMessageOpcode.SCENE_STATUS,
-        SceneMessageOpcode.SCENE_REGISTER_GET,
-        SceneMessageOpcode.SCENE_REGISTER_STATUS,
-        SceneMessageOpcode.SCENE_STORE,
-        SceneMessageOpcode.SCENE_STORE_UNACKNOWLEDGED,
-        SceneMessageOpcode.SCENE_DELETE,
-        SceneMessageOpcode.SCENE_DELETE_UNACKNOWLEDGED,
+        SceneOpcode.SCENE_GET,
+        SceneOpcode.SCENE_RECALL,
+        SceneOpcode.SCENE_RECALL_UNACKNOWLEDGED,
+        SceneOpcode.SCENE_STATUS,
+        SceneOpcode.SCENE_REGISTER_GET,
+        SceneOpcode.SCENE_REGISTER_STATUS,
+        SceneOpcode.SCENE_STORE,
+        SceneOpcode.SCENE_STORE_UNACKNOWLEDGED,
+        SceneOpcode.SCENE_DELETE,
+        SceneOpcode.SCENE_DELETE_UNACKNOWLEDGED,
     }
 
     def __init__(self, element: "Element"):
@@ -1171,7 +1171,7 @@ class SceneClient(Model):
             ret = self.send_app(
                 destination,
                 app_index=app_index,
-                opcode=SceneMessageOpcode.SCENE_RECALL_UNACKNOWLEDGED,
+                opcode=SceneOpcode.SCENE_RECALL_UNACKNOWLEDGED,
                 params=dict(
                     scene_number=scene_number,
                     tid=values["tid"],
@@ -1252,6 +1252,16 @@ class LightLightnessServer(Model):
     }
 
 
+class LightLightnessSetupServer(Model):
+    MODEL_ID = (None, 0x1301)
+    OPCODES = {
+        LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET,
+        LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET_UNACKNOWLEDGED,
+        LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET,
+        LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
+    }
+
+
 class LightLightnessClient(Model):
     MODEL_ID = (None, 0x1302)
     OPCODES = {
@@ -1259,6 +1269,7 @@ class LightLightnessClient(Model):
         LightLightnessOpcode.LIGHTNESS_SET,
         LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED,
         LightLightnessOpcode.LIGHTNESS_STATUS,
+        LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
     }
     _tid = 0
 
@@ -1267,6 +1278,31 @@ class LightLightnessClient(Model):
         self._tid = (self._tid + 1) % 255
         return self._tid
 
+    async def set_lightness_range_unack(
+        self,
+        destination: int,
+        app_index: int,
+        min_lightness: int,
+        max_lightness: int,
+        *,
+        retransmissions: int = 6,
+        send_interval: float = 0.075,
+    ) -> None:
+        async def request():
+            ret = self.send_app(
+                destination,
+                app_index=app_index,
+                opcode=LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
+                params=dict(
+                    range_min=min_lightness,
+                    range_max=max_lightness,
+                ),
+            )
+
+            return await ret
+
+        await self.repeat(request, retransmissions=retransmissions, send_interval=send_interval)
+
     async def get_lightness(
         self,
         nodes: Sequence[int],
